searchData={"items":[{"type":"module","title":"SimpleFeatureFlags","doc":"This module includes functions for checking whether a feature is enabled (`enabled?/1`), and for introspecting configuration (`current_configuration_to_string/0`).","ref":"SimpleFeatureFlags.html"},{"type":"function","title":"SimpleFeatureFlags.current_configuration_to_string/0","doc":"Return the current configuration as a human-friendly string.","ref":"SimpleFeatureFlags.html#current_configuration_to_string/0"},{"type":"function","title":"Examples - SimpleFeatureFlags.current_configuration_to_string/0","doc":"iex> SimpleFeatureFlags.current_configuration_to_string()\n    \"Current Deployment Environment: :test\\nFeatures:\\n - test_feature_1 is ON. Enabled in [:all]\\n - test_feature_2 is ON. Enabled in :all\\n - test_feature_3 is ON. Enabled in [:test]\\n - test_feature_4 is ON. Enabled in [:staging, :test, :production]\\n - test_feature_5 is OFF. Enabled in [:staging, :production]\\n - test_feature_6 is OFF. Enabled in []\\n\"","ref":"SimpleFeatureFlags.html#current_configuration_to_string/0-examples"},{"type":"function","title":"SimpleFeatureFlags.enabled?/1","doc":"Is feature x enabled in the current deployment environment?","ref":"SimpleFeatureFlags.html#enabled?/1"},{"type":"function","title":"Examples - SimpleFeatureFlags.enabled?/1","doc":"iex> SimpleFeatureFlags.enabled?(:test_feature_1)\n    true","ref":"SimpleFeatureFlags.html#enabled?/1-examples"},{"type":"extras","title":"README","doc":"# README\n\nSimpleFeatureFlags provides basic, simple feature flag functionality. You can use application configuration (`config/runtime.exs`) to select the deployment environments in which a feature is enabled\n\nThis approach is useful when you want to roll out a feature to only a subset of your environments. Here are a couple of examples:\n1. You want to try a feature in your localhost and staging environments, before rolling it out to production.\n2. You want to use a feature in a subset of your production environments (based on a region, or some other grouping).\n\nThe example below describes switching to a new, exciting algorithm (`:new_algorithm`) for computing `𝝿` in `:localhost` and `:staging` deployment environments, before rolling it out to `:production` (or not).","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `simple_feature_flags` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simple_feature_flags, \"~> 0.1\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - README","doc":"Determine the name of the deployment environment you are running in, and list the environments in which your feature is enabled.\n\nIn this example, the name of the deployment environment is loaded from an environment variable, and the `new_algorithm` feature is enabled in `localhost` and `staging`:\n\n\n`config/runtime.exs`\n```elixir\ncurrent_deployment_environment =\n  System.get_env(\"DEPLOYMENT_ENVIRONMENT\")\n  |> case do\n    nil -> raise \"DEPLOYMENT_ENVIRONMENT is not defined\"\n    env -> String.to_atom(env)\n  end\n\n\nconfig :simple_feature_flags, :flags, %{\n  current_deployment_environment: current_deployment_environment,\n  features: %{\n    new_algorithm: %{enabled_in: [:localhost, :staging]},\n    new_ui: %{enabled_in: [:staging]}\n  }\n}\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Using Feature Flag in Your Code - README","doc":"Wrap your feature logic in `SimpleFeatureFlags.enabled?/1`:\n\n```elixir\ndefmodule MyApp.Pi do\n  def compute_pi() do\n    if SimpleFeatureFlags.enabled?(:new_algorithm) do\n      # Use the new, exciting algorithm.\n      compute_pi_new_algorithm()\n    else\n      # Use the old, boring algorithm.\n      3.14\n    end\n  end\nend\n```","ref":"readme.html#using-feature-flag-in-your-code"},{"type":"extras","title":"Optional: Log Configuration on Startup - README","doc":"`lib/myapp/application.ex`\n\n```elixir\ndefmodule MyApp.Application do\n\n  require Logger\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    Logger.info(SimpleFeatureFlags.current_configuration_to_string())\n    ...\n```\n\nHere is an example of the output:\n\n```text\n  Current Deployment Environment: :localhost\n  Features:\n  - new_algorithm is ON. Enabled in [:localhost, :staging]\n  - new_ui is OFF. Enabled in [:staging]\n```","ref":"readme.html#optional-log-configuration-on-startup"},{"type":"extras","title":"Completing the Experiment: Retiring `:new_algorithm` or Rolling it Out to `:production` - README","doc":"If, after experiencing `:new_algorithm` is `:localhost` and `:staging`, you decided that the world is not ready for its genius, you can simply remove `new_algorithm` and its implementation from configs and the codebase.\n\nIf you are now confident that this `new_algorithm` for computing `𝝿` will make the world and your product better, and you want to roll it out to production, you have a couple of options:\n\n1. Remove the feature flag completely. The new feature is now part of your codebase.\n2. Add your production environment to the `enabled_in:` list, or replace the list with `:all`:\n   * `new_algorithm: %{enabled_in: [:localhost, :staging: :production]},` OR\n   * `new_algorithm: %{enabled_in: :all},`.","ref":"readme.html#completing-the-experiment-retiring-new_algorithm-or-rolling-it-out-to-production"},{"type":"extras","title":"A/B, Regional Testing - README","doc":"The example above alluded to the existence of `:localhost`, `:staging`, and `:production` deployment environments.\n\nThe configuration approach of choosing the environments in which your changes are live remains the same, regardless of how many production or staging environments you have: simply detect `current_deployment_environment` in which the code is running, and include all environments of interest in the `enabled_in` list.\n\nFor example, to roll `:new_algorithm` out to your production environment running in Singapore, but not to the US or Japan, you might do something like this:  \n\n`config/runtime.exs`\n```elixir\n# e.g. :localhost, :staging, :production_us, :production_sg, :production_jp\n# Detect this in runtime.\ncurrent_deployment_environment = ... \n\nconfig :simple_feature_flags, :flags, %{\n  current_deployment_environment: current_deployment_environment,\n  features: %{\n    # enabled in production in Singapore.\n    new_algorithm: %{enabled_in: [:localhost, :staging, :production_sg]},\n  }\n}\n```","ref":"readme.html#a-b-regional-testing"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2023-2025 Mark Markaryan\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}